/*
 * Copyright 2007 Evan Cowden
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0 
 * 
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License.
 */
package org.nakedosgi.annotations.scr;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;

/**
 * Representation of an OSGi service reference cardinality.  Use 
 * {@code value()} to get the OSGi standard string representation of the 
 * associated value.
 * @author Evan Cowden
 */
@XmlEnum
public enum Cardinality {

    /**
     * 0..1
     */
    @XmlEnumValue("0..1")
    ZERO_OR_ONE("0..1"),
    /**
     * 0..n
     */
    
    @XmlEnumValue("0..n")
    ZERO_OR_MORE("0..n"),
    /*
     * 1..1
     */
    
    @XmlEnumValue("1..1")
    EXACTLY_ONE("1..1"),
    /**
     * 1..n
     */
    
    @XmlEnumValue("1..n")
    ONE_OR_MORE("1..n");
    private final String value;

    Cardinality(String value) {
        this.value = value;
    }

    public String value() {
        return value;
    }
}
