/*
 * Copyright 2008 Evan Cowden
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0 
 * 
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License.
 */
package org.nakedosgi.util;

/**
 * Utility class for {@code java.lang.String}s
 * @author Evan Cowden
 */
public abstract class Strings {

    /**
     * <p>Simple var-arg {@code String} builder.  Builds a String by concatonating the
     * parameter objects.  Internally, this method uses a {@code StringBuilder}, 
     * making it more efficient than String concatonation using '+'.</p>
     * 
     * <p>The String value of each object is determined by
     * calling its {@code toString()} method.</p>
     * 
     * @param objects
     * @return 
     */
    public static String build(Object... objects) {
        StringBuilder builder = new StringBuilder();
        for (int i = 0; i < objects.length; i++) { //For speed
            builder.append(objects[i].toString());
        }

        return builder.toString();
    }
}
